# PocBot

## Description
Simple streamlit UI to implement chatbots.
- Objective: Develop a pip installable package to create easy ChatBot interfaces.
- Scope: First iteration - Base this on what was done in the [e-commerce chatbot](https://github.com/thisisqubika/data-studio-e-commerce)

## Installation
Instructions on how to install the project

## Usage
Instructions on how to use the project

## Contributing
Instructions on how to contribute to the project

## References
Link to references used in the project (Books, posts, videos, courses, repos, etc.)
